@@ -44,9 +44,10 @@ func createAppWithSubnets(t *testing.T, db *dbops.PgDB, index int64, v4Config, v
 
 	// Creates new app with provided configurations.
 	accessPoints := []*dbmodel.AccessPoint{}
-	accessPoints = dbmodel.AppendAccessPoint(accessPoints, dbmodel.AccessPointControl, "localhost", "", 8000)
+	accessPoints = dbmodel.AppendAccessPoint(accessPoints, dbmodel.AccessPointControl, "localhost", "", 8000, true)
 	app := dbmodel.App{
 		MachineID:    m.ID,
+		Machine:      m,
 		Type:         dbmodel.AppTypeKea,
 		AccessPoints: accessPoints,
 		Daemons: []*dbmodel.Daemon{
