@@ -9,6 +9,7 @@ import (
 	"isc.org/stork/server/agentcomm"
 	"isc.org/stork/server/apps/bind9"
 	"isc.org/stork/server/apps/kea"
+	"isc.org/stork/server/configreview"
 	dbops "isc.org/stork/server/database"
 	dbmodel "isc.org/stork/server/database/model"
 	"isc.org/stork/server/eventcenter"
@@ -18,16 +19,18 @@ import (
 // Besides basic status information the High Availability status is fetched.
 type StatePuller struct {
 	*agentcomm.PeriodicPuller
-	EventCenter eventcenter.EventCenter
+	EventCenter      eventcenter.EventCenter
+	ReviewDispatcher configreview.Dispatcher
 }
 
 // Create an instance of the puller which periodically checks the status of
 // the Kea apps.
-func NewStatePuller(db *dbops.PgDB, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter) (*StatePuller, error) {
+func NewStatePuller(db *dbops.PgDB, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter, reviewDispatcher configreview.Dispatcher) (*StatePuller, error) {
 	puller := &StatePuller{
-		EventCenter: eventCenter,
+		EventCenter:      eventCenter,
+		ReviewDispatcher: reviewDispatcher,
 	}
-	periodicPuller, err := agentcomm.NewPeriodicPuller(db, agents, "Apps State",
+	periodicPuller, err := agentcomm.NewPeriodicPuller(db, agents, "Apps State puller",
 		"apps_state_puller_interval", puller.pullData)
 	if err != nil {
 		return nil, err
@@ -42,12 +45,12 @@ func (puller *StatePuller) Shutdown() {
 }
 
 // Gets the status of machines and their apps and stores useful information in the database.
-func (puller *StatePuller) pullData() (int, error) {
+func (puller *StatePuller) pullData() error {
 	// get list of all authorized machines from database
 	authorized := true
 	dbMachines, err := dbmodel.GetAllMachines(puller.DB, &authorized)
 	if err != nil {
-		return 0, err
+		return err
 	}
 
 	// get state from machines and their apps
@@ -56,7 +59,7 @@ func (puller *StatePuller) pullData() (int, error) {
 	for _, dbM := range dbMachines {
 		dbM2 := dbM
 		ctx := context.Background()
-		errStr := GetMachineAndAppsState(ctx, puller.DB, &dbM2, puller.Agents, puller.EventCenter)
+		errStr := GetMachineAndAppsState(ctx, puller.DB, &dbM2, puller.Agents, puller.EventCenter, puller.ReviewDispatcher)
 		if errStr != "" {
 			lastErr = errors.New(errStr)
 			log.Errorf("error occurred while getting info from machine %d: %s", dbM2.ID, errStr)
@@ -65,7 +68,7 @@ func (puller *StatePuller) pullData() (int, error) {
 		}
 	}
 	log.Printf("completed pulling information from machines: %d/%d succeeded", okCnt, len(dbMachines))
-	return okCnt, lastErr
+	return lastErr
 }
 
 // Store updated machine fields in to database.
@@ -230,7 +233,7 @@ func mergeNewAndOldApps(db *dbops.PgDB, dbMachine *dbmodel.Machine, discoveredAp
 }
 
 // Retrieve remotely machine and its apps state, and store it in the database.
-func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmodel.Machine, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter) string {
+func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmodel.Machine, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter, reviewDispatcher configreview.Dispatcher) string {
 	ctx2, cancel := context.WithTimeout(ctx, 10*time.Second)
 	defer cancel()
 
@@ -268,6 +271,26 @@ func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 		case dbmodel.AppTypeKea:
 			state := kea.GetAppState(ctx2, agents, dbApp, eventCenter)
 			err = kea.CommitAppIntoDB(db, dbApp, eventCenter, state)
+			if err == nil {
+				// Let's now identify new daemons or the daemons with updated
+				// configurations and schedule configuration reviews for them
+				for i, daemon := range dbApp.Daemons {
+					if state != nil && state.SameConfigDaemons != nil {
+						if ok := state.SameConfigDaemons[daemon.Name]; ok {
+							// Configuration of this daemon hasn't changed. Don't
+							// run the configuration review.
+							continue
+						}
+					}
+					// It is a new daemon or its configuration has been recently updated.
+					// Let's make sure that the config pointer is set. It can be nil
+					// when the daemon is inactive.
+					if daemon.KeaDaemon != nil && daemon.KeaDaemon.Config != nil {
+						_ = reviewDispatcher.BeginReview(dbApp.Daemons[i], nil)
+					}
+				}
+			}
+
 		case dbmodel.AppTypeBind9:
 			bind9.GetAppState(ctx2, agents, dbApp, eventCenter)
 			err = bind9.CommitAppIntoDB(db, dbApp, eventCenter)
