@@ -26,11 +26,12 @@ func TestStatsPullerBasic(t *testing.T) {
 	err := db.Insert(&setting)
 	require.NoError(t, err)
 
-	// prepare fake agents and event center
+	// Fake agents, event center and config review dispatcher.
 	fa := agentcommtest.NewFakeAgents(nil, nil)
 	fec := &storktest.FakeEventCenter{}
+	fd := &storktest.FakeDispatcher{}
 
-	sp, err := NewStatePuller(db, fa, fec)
+	sp, err := NewStatePuller(db, fa, fec, fd)
 	require.NoError(t, err)
 	require.NotNil(t, sp.PeriodicPuller)
 
@@ -61,6 +62,9 @@ func TestStatePullerPullData(t *testing.T) {
 	// prepare fake event center
 	fec := &storktest.FakeEventCenter{}
 
+	// fake config review dispatcher
+	fd := &storktest.FakeDispatcher{}
+
 	// add one machine with one kea app
 	m := &dbmodel.Machine{
 		ID:         0,
@@ -72,6 +76,9 @@ func TestStatePullerPullData(t *testing.T) {
 	require.NoError(t, err)
 	require.NotEqual(t, 0, m.ID)
 
+	config, err := dbmodel.NewKeaConfigFromJSON(`{"Dhcp4": { }}`)
+	require.NoError(t, err)
+
 	var ap []*dbmodel.AccessPoint
 	a := &dbmodel.App{
 		ID:        0,
@@ -85,6 +92,7 @@ func TestStatePullerPullData(t *testing.T) {
 				Active: true,
 				Name:   "dhcp4",
 				KeaDaemon: &dbmodel.KeaDaemon{
+					Config:        config,
 					KeaDHCPDaemon: &dbmodel.KeaDHCPDaemon{},
 				},
 			},
@@ -104,15 +112,14 @@ func TestStatePullerPullData(t *testing.T) {
 	require.NoError(t, err)
 
 	// prepare stats puller
-	sp, err := NewStatePuller(db, fa, fec)
+	sp, err := NewStatePuller(db, fa, fec, fd)
 	require.NoError(t, err)
 	// shutdown state puller at the end
 	defer sp.Shutdown()
 
 	// invoke pulling state
-	appsOkCnt, err := sp.pullData()
+	err = sp.pullData()
 	require.NoError(t, err)
-	require.Equal(t, 1, appsOkCnt)
 
 	// check if apps have been updated correctly
 	apps, err := dbmodel.GetAllApps(db, true)
@@ -126,6 +133,10 @@ func TestStatePullerPullData(t *testing.T) {
 	}
 	require.Len(t, keaApp.AccessPoints, 1)
 	require.EqualValues(t, keaApp.AccessPoints[0].Address, "1.2.3.4")
+
+	// Ensure that the puller initiated configuration review for the Kea daemon.
+	require.Len(t, fd.CallLog, 1)
+	require.Equal(t, "BeginReview", fd.CallLog[0])
 }
 
 // Check appCompare.
