@@ -54,7 +54,8 @@ func TestInnerMiddleware(t *testing.T) {
 	settings := RestAPISettings{}
 	fa := agentcommtest.NewFakeAgents(nil, nil)
 	fec := &storktest.FakeEventCenter{}
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec, nil)
+	fd := &storktest.FakeDispatcher{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec, nil, fd, nil)
 	require.NoError(t, err)
 	sm, err := dbsession.NewSessionMgr(&rapi.DBSettings.BaseDatabaseSettings)
 	require.NoError(t, err)
@@ -132,6 +133,42 @@ func TestAgentInstallerMiddleware(t *testing.T) {
 	require.True(t, requestReceived)
 }
 
+// Check if metricsMiddelware works and handles requests correctly.
+func TestMetricsMiddleware(t *testing.T) {
+	// Arrange
+	metrics := storktest.NewFakeMetricsCollector()
+	nextHandler := http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {})
+	handler := metricsMiddleware(nextHandler, metrics)
+
+	// Act
+	req := httptest.NewRequest("GET", "http://localhost/metrics", nil)
+	w := httptest.NewRecorder()
+	handler.ServeHTTP(w, req)
+
+	// Assert
+	require.EqualValues(t, 1, metrics.RequestCount)
+}
+
+// Check if metricsMiddelware returns placeholder when the endpoint is disabled.
+func TestMetricsMiddlewarePlaceholder(t *testing.T) {
+	// Arrange
+	nextHandler := http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {})
+	handler := metricsMiddleware(nextHandler, nil)
+
+	// Act
+	req := httptest.NewRequest("GET", "http://localhost/metrics", nil)
+	w := httptest.NewRecorder()
+	handler.ServeHTTP(w, req)
+	resp := w.Result()
+	content, err := ioutil.ReadAll(resp.Body)
+	defer resp.Body.Close()
+
+	// Assert
+	require.NoError(t, err)
+	require.EqualValues(t, 503, resp.StatusCode)
+	require.EqualValues(t, "The metrics collector endpoint is disabled.", content)
+}
+
 // Dumb response writer struct with functions to enable testing
 // loggingResponseWriter.
 type dumbRespWritter struct{}
